Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon API Gateway Management.

Actions, resources, and condition keys for Amazon API Gateway Management - Service Authorization Reference

# Actions, resources, and condition keys for Amazon API Gateway Management

Amazon API Gateway Management (service prefix: `apigateway` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon API Gateway Management
- Resource types defined by Amazon API Gateway Management
- Condition keys for Amazon API Gateway Management

## Actions defined by Amazon API Gateway Management

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddCertificateToDomain | Grants permission to add certificates for mutual TLS authentication to a domain name. This is an additional authorization control for managing the DomainName resource due to the sensitive nature of mTLS | Permissions management | DomainName |  |
DomainNames |  |
DELETE | Grants permission to delete a particular resource | Write | ApiKey |  |
Authorizer |  |
BasePathMapping |  |
ClientCertificate |  |
Deployment |  |
DocumentationPart |  |
DocumentationVersion |  |
DomainName |  |
GatewayResponse |  |
Integration |  |
IntegrationResponse |  |
Method |  |
MethodResponse |  |
Model |  |
RequestValidator |  |
Resource |  |
RestApi |  |
Stage |  |
Tags |  |
Template |  |
UsagePlan |  |
UsagePlanKey |  |
VpcLink |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
GET | Grants permission to read a particular resource | Read | Account |  |
ApiKey |  |
ApiKeys |  |
Authorizer |  |
Authorizers |  |
BasePathMapping |  |
BasePathMappings |  |
ClientCertificate |  |
ClientCertificates |  |
Deployment |  |
Deployments |  |
DocumentationPart |  |
DocumentationParts |  |
DocumentationVersion |  |
DocumentationVersions |  |
DomainName |  |
DomainNames |  |
GatewayResponse |  |
GatewayResponses |  |
Integration |  |
IntegrationResponse |  |
Method |  |
MethodResponse |  |
Model |  |
Models |  |
RequestValidator |  |
RequestValidators |  |
Resource |  |
Resources |  |
RestApi |  |
RestApis |  |
Sdk |  |
Stage |  |
Stages |  |
Tags |  |
UsagePlan |  |
UsagePlanKey |  |
UsagePlanKeys |  |
UsagePlans |  |
VpcLink |  |
VpcLinks |  |
PATCH | Grants permission to update a particular resource | Write | Account |  |
ApiKey |  |
Authorizer |  |
BasePathMapping |  |
ClientCertificate |  |
Deployment |  |
DocumentationPart |  |
DocumentationVersion |  |
DomainName |  |
GatewayResponse |  |
Integration |  |
IntegrationResponse |  |
Method |  |
MethodResponse |  |
Model |  |
RequestValidator |  |
Resource |  |
RestApi |  |
Stage |  |
Template |  |
UsagePlan |  |
UsagePlanKey |  |
VpcLink |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
POST | Grants permission to create a particular resource | Write | ApiKeys |  |
Authorizers |  |
BasePathMappings |  |
ClientCertificates |  |
Deployments |  |
DocumentationParts |  |
DocumentationVersions |  |
DomainNames |  |
GatewayResponses |  |
IntegrationResponse |  |
MethodResponse |  |
Models |  |
RequestValidators |  |
Resources |  |
RestApis |  |
Stages |  |
UsagePlanKeys |  |
UsagePlans |  |
VpcLinks |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
PUT | Grants permission to update a particular resource | Write | DocumentationPart |  |
GatewayResponse |  |
IntegrationResponse |  |
MethodResponse |  |
RestApi |  |
Tags |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
RemoveCertificateFromDomain | Grants permission to remove certificates for mutual TLS authentication from a domain name. This is an additional authorization control for managing the DomainName resource due to the sensitive nature of mTLS | Permissions management | DomainName |  |
DomainNames |  |
SetWebACL | Grants permission to set a WAF access control list (ACL). This is an additional authorization control for managing the Stage resource due to the sensitive nature of WebAcl's | Permissions management | Stage |  |
Stages |  |
UpdateRestApiPolicy | Grants permission to manage the IAM resource policy for an API. This is an additional authorization control for managing an API due to the sensitive nature of the resource policy | Permissions management | RestApi |  |
RestApis |  |

## Resource types defined by Amazon API Gateway Management

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
Account | `arn:$ { Partition}:apigateway:$ { Region}::/account` |
ApiKey | `arn:$ { Partition}:apigateway:$ { Region}::/apikeys/$ { ApiKeyId}` | aws:ResourceTag/${TagKey}
ApiKeys | `arn:$ { Partition}:apigateway:$ { Region}::/apikeys` | aws:ResourceTag/${TagKey}
Authorizer | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/authorizers/$ { AuthorizerId}` | apigateway:Request/AuthorizerType apigateway:Request/AuthorizerUri apigateway:Resource/AuthorizerType apigateway:Resource/AuthorizerUri aws:ResourceTag/${TagKey}
Authorizers | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/authorizers` | apigateway:Request/AuthorizerType apigateway:Request/AuthorizerUri aws:ResourceTag/${TagKey}
BasePathMapping | `arn:$ { Partition}:apigateway:$ { Region}::/domainnames/$ { DomainName}/basepathmappings/$ { BasePath}` | aws:ResourceTag/${TagKey}
BasePathMappings | `arn:$ { Partition}:apigateway:$ { Region}::/domainnames/$ { DomainName}/basepathmappings` | aws:ResourceTag/${TagKey}
ClientCertificate | `arn:$ { Partition}:apigateway:$ { Region}::/clientcertificates/$ { ClientCertificateId}` | aws:ResourceTag/${TagKey}
ClientCertificates | `arn:$ { Partition}:apigateway:$ { Region}::/clientcertificates` | aws:ResourceTag/${TagKey}
Deployment | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/deployments/$ { DeploymentId}` | aws:ResourceTag/${TagKey}
Deployments | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/deployments` | apigateway:Request/StageName
DocumentationPart | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/documentation/parts/$ { DocumentationPartId}` | aws:ResourceTag/${TagKey}
DocumentationParts | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/documentation/parts` | aws:ResourceTag/${TagKey}
DocumentationVersion | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/documentation/versions/$ { DocumentationVersionId}` |
DocumentationVersions | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/documentation/versions` |
DomainName | `arn:$ { Partition}:apigateway:$ { Region}::/domainnames/$ { DomainName}` | apigateway:Request/EndpointType apigateway:Request/MtlsTrustStoreUri apigateway:Request/MtlsTrustStoreVersion apigateway:Request/SecurityPolicy apigateway:Resource/EndpointType apigateway:Resource/MtlsTrustStoreUri apigateway:Resource/MtlsTrustStoreVersion apigateway:Resource/SecurityPolicy aws:ResourceTag/${TagKey}
DomainNames | `arn:$ { Partition}:apigateway:$ { Region}::/domainnames` | apigateway:Request/EndpointType apigateway:Request/MtlsTrustStoreUri apigateway:Request/MtlsTrustStoreVersion apigateway:Request/SecurityPolicy aws:ResourceTag/${TagKey}
GatewayResponse | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/gatewayresponses/$ { ResponseType}` | aws:ResourceTag/${TagKey}
GatewayResponses | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/gatewayresponses` | aws:ResourceTag/${TagKey}
Integration | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/resources/$ { ResourceId}/methods/$ { HttpMethodType}/integration` | aws:ResourceTag/${TagKey}
IntegrationResponse | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/resources/$ { ResourceId}/methods/$ { HttpMethodType}/integration/responses/$ { StatusCode}` |
Method | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/resources/$ { ResourceId}/methods/$ { HttpMethodType}` | apigateway:Request/ApiKeyRequired apigateway:Request/RouteAuthorizationType apigateway:Resource/ApiKeyRequired apigateway:Resource/RouteAuthorizationType aws:ResourceTag/${TagKey}
MethodResponse | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/resources/$ { ResourceId}/methods/$ { HttpMethodType}/responses/$ { StatusCode}` |
Model | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/models/$ { ModelName}` | aws:ResourceTag/${TagKey}
Models | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/models` | aws:ResourceTag/${TagKey}
RequestValidator | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/requestvalidators/$ { RequestValidatorId}` |
RequestValidators | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/requestvalidators` |
Resource | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/resources/$ { ResourceId}` | aws:ResourceTag/${TagKey}
Resources | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/resources` | aws:ResourceTag/${TagKey}
RestApi | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}` | apigateway:Request/ApiKeyRequired apigateway:Request/ApiName apigateway:Request/AuthorizerType apigateway:Request/AuthorizerUri apigateway:Request/DisableExecuteApiEndpoint apigateway:Request/EndpointType apigateway:Request/RouteAuthorizationType apigateway:Resource/ApiKeyRequired apigateway:Resource/ApiName apigateway:Resource/AuthorizerType apigateway:Resource/AuthorizerUri apigateway:Resource/DisableExecuteApiEndpoint apigateway:Resource/EndpointType apigateway:Resource/RouteAuthorizationType aws:ResourceTag/${TagKey}
RestApis | `arn:$ { Partition}:apigateway:$ { Region}::/restapis` | apigateway:Request/ApiKeyRequired apigateway:Request/ApiName apigateway:Request/AuthorizerType apigateway:Request/AuthorizerUri apigateway:Request/DisableExecuteApiEndpoint apigateway:Request/EndpointType apigateway:Request/RouteAuthorizationType aws:ResourceTag/${TagKey}
Sdk | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/stages/$ { StageName}/sdks/$ { SdkType}` |
Stage | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/stages/$ { StageName}` | apigateway:Request/AccessLoggingDestination apigateway:Request/AccessLoggingFormat apigateway:Resource/AccessLoggingDestination apigateway:Resource/AccessLoggingFormat aws:ResourceTag/${TagKey}
Stages | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/$ { RestApiId}/stages` | apigateway:Request/AccessLoggingDestination apigateway:Request/AccessLoggingFormat aws:ResourceTag/${TagKey}
Template | `arn:$ { Partition}:apigateway:$ { Region}::/restapis/models/$ { ModelName}/template` |
UsagePlan | `arn:$ { Partition}:apigateway:$ { Region}::/usageplans/$ { UsagePlanId}` | aws:ResourceTag/${TagKey}
UsagePlans | `arn:$ { Partition}:apigateway:$ { Region}::/usageplans` | aws:ResourceTag/${TagKey}
UsagePlanKey | `arn:$ { Partition}:apigateway:$ { Region}::/usageplans/$ { UsagePlanId}/keys/$ { Id}` |
UsagePlanKeys | `arn:$ { Partition}:apigateway:$ { Region}::/usageplans/$ { UsagePlanId}/keys` |
VpcLink | `arn:$ { Partition}:apigateway:$ { Region}::/vpclinks/$ { VpcLinkId}` | aws:ResourceTag/${TagKey}
VpcLinks | `arn:$ { Partition}:apigateway:$ { Region}::/vpclinks` | aws:ResourceTag/${TagKey}
Tags | `arn:$ { Partition}:apigateway:$ { Region}::/tags/$ { UrlEncodedResourceARN}` |

## Condition keys for Amazon API Gateway Management

Amazon API Gateway Management defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
apigateway:Request/AccessLoggingDestination | Filters access by access log destination. Available during the CreateStage and UpdateStage operations | String
apigateway:Request/AccessLoggingFormat | Filters access by access log format. Available during the CreateStage and UpdateStage operations | String
apigateway:Request/ApiKeyRequired | Filters access by whether an API key is required or not. Available during the CreateMethod and PutMethod operations. Also available as a collection during import and reimport | ArrayOfBool
apigateway:Request/ApiName | Filters access by API name. Available during the CreateRestApi and UpdateRestApi operations | String
apigateway:Request/AuthorizerType | Filters access by type of authorizer in the request, for example TOKEN, REQUEST, JWT. Available during CreateAuthorizer and UpdateAuthorizer. Also available during import and reimport as an ArrayOfString | ArrayOfString
apigateway:Request/AuthorizerUri | Filters access by URI of a Lambda authorizer function. Available during CreateAuthorizer and UpdateAuthorizer. Also available during import and reimport as an ArrayOfString | ArrayOfString
apigateway:Request/DisableExecuteApiEndpoint | Filters access by status of the default execute-api endpoint. Available during the CreateRestApi and DeleteRestApi operations | Bool
apigateway:Request/EndpointType | Filters access by endpoint type. Available during the CreateDomainName, UpdateDomainName, CreateRestApi, and UpdateRestApi operations | ArrayOfString
apigateway:Request/MtlsTrustStoreUri | Filters access by URI of the truststore used for mutual TLS authentication. Available during the CreateDomainName and UpdateDomainName operations | String
apigateway:Request/MtlsTrustStoreVersion | Filters access by version of the truststore used for mutual TLS authentication. Available during the CreateDomainName and UpdateDomainName operations | String
apigateway:Request/RouteAuthorizationType | Filters access by authorization type, for example NONE, AWS_IAM, CUSTOM, JWT, COGNITO_USER_POOLS. Available during the CreateMethod and PutMethod operations Also available as a collection during import | ArrayOfString
apigateway:Request/SecurityPolicy | Filters access by TLS version. Available during the CreateDomain and UpdateDomain operations | ArrayOfString
apigateway:Request/StageName | Filters access by stage name of the deployment that you attempt to create. Available during the CreateDeployment operation | String
apigateway:Resource/AccessLoggingDestination | Filters access by access log destination of the current Stage resource. Available during the UpdateStage and DeleteStage operations | String
apigateway:Resource/AccessLoggingFormat | Filters access by access log format of the current Stage resource. Available during the UpdateStage and DeleteStage operations | String
apigateway:Resource/ApiKeyRequired | Filters access by whether an API key is required or not for the existing Method resource. Available during the PutMethod and DeleteMethod operations. Also available as a collection during reimport | ArrayOfBool
apigateway:Resource/ApiName | Filters access by API name of the existing RestApi resource. Available during UpdateRestApi and DeleteRestApi operations | String
apigateway:Resource/AuthorizerType | Filters access by the current type of authorizer, for example TOKEN, REQUEST, JWT. Available during UpdateAuthorizer and DeleteAuthorizer operations. Also available during reimport as an ArrayOfString | ArrayOfString
apigateway:Resource/AuthorizerUri | Filters access by URI of a Lambda authorizer function. Available during UpdateAuthorizer and DeleteAuthorizer operations. Also available during reimport as an ArrayOfString | ArrayOfString
apigateway:Resource/DisableExecuteApiEndpoint | Filters access by status of the default execute-api endpoint of the current RestApi resource. Available during UpdateRestApi and DeleteRestApi operations | Bool
apigateway:Resource/EndpointType | Filters access by endpoint type. Available during the UpdateDomainName, DeleteDomainName, UpdateRestApi, and DeleteRestApi operations | ArrayOfString
apigateway:Resource/MtlsTrustStoreUri | Filters access by URI of the truststore used for mutual TLS authentication. Available during UpdateDomainName and DeleteDomainName operations | String
apigateway:Resource/MtlsTrustStoreVersion | Filters access by version of the truststore used for mutual TLS authentication. Available during UpdateDomainName and DeleteDomainName operations | String
apigateway:Resource/RouteAuthorizationType | Filters access by authorization type of the existing Method resource, for example NONE, AWS_IAM, CUSTOM, JWT, COGNITO_USER_POOLS. Available during the PutMethod and DeleteMethod operations. Also available as a collection during reimport | ArrayOfString
apigateway:Resource/SecurityPolicy | Filters access by TLS version. Available during UpdateDomain and DeleteDomain operations | ArrayOfString
aws:RequestTag/${TagKey} | Filters access by the tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags attached to the resource | String
aws:TagKeys | Filters access by the tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.